@@ -5,7 +5,7 @@
  * @name newElement
  * @kind function
  * @param {Object<JSON>} jsn - JSON object
- * @param {String} jsn.el    - HTML element name
+ * @param {String} jsn.element    - HTML element name
  * @param {String} jsn.id    - ID of the element
  * @param {Array<String>} jsn.cls - classes of the element
  * @param {Array<Array<String>>} jsn.attr - Attriburtes of the HTML element
@@ -13,7 +13,7 @@
  * @returns {HTMLElement} 
  */
 function newElement(jsn, DOM_Element) {
-  let e = document.createElement(jsn.el);
+  let e = document.createElement(jsn.element);
   if (jsn.cls) {
     jsn.cls.forEach((el) => {
       e.classList.add(el);
