@@ -155,11 +155,17 @@ function langSelected(lang) {
  * It fetches the JSON file, then calls the _Translate function with the JSON file as an argument.
  */
 function translatejs() {
-  fetch("/production/localisation/lang.json?v=1", {
-    mode: "no-cors",
-  }) // disable CORS because path does not contain http(s)
-    .then((res) => res.json())
-    .then((data) => (_Translate(data)));
+  try {
+    fetch("/production/localisation/lang.json?v=1", {
+      mode: "no-cors",
+    }) // disable CORS because path does not contain http(s)
+      .then((res) => res.json())
+      .then((data) => (_Translate(data)));
+  } catch (error) {
+    console.log(error);
+  }
+
+
 }
 
 $(document).ready(function () {
