@@ -156,10 +156,11 @@ function downloadFile() {
         oReq.open("GET", url, true);
         oReq.send();
 
+        console.log(oReq.progress);
         /* Setting the value of the element with the id `updatemassage` to the value of the response. */
         oReq.onload = function(e) {
-            console.log(oReq);
             var arraybuffer = oReq.response; // not responseText
+            console.log(arraybuffer);
             if (arraybuffer.includes("Error: 500")) {
                 document.getElementById("updatemassage").value = "UPDATE FEHLGESCHLAGEN"
             } else {
@@ -167,6 +168,7 @@ function downloadFile() {
             }
             setTimeout(function() {
                 gears_off()
+                setReboot()
             }, 500);
         }
 
@@ -221,7 +223,7 @@ function downloadFile() {
             document.getElementById('updatemassage').value = "Einen Moment bitte"
         }
         // document.getElementById("message").innerHTML = "";
-
+//
         // /* Sending a request to the server. */
         // httpSetconfig.open("GET", url, true);
         // httpSetconfig.send();
